"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var BlockchainActionsProcessor_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockchainActionsProcessor = void 0;
const bull_1 = require("@nestjs/bull");
const common_1 = require("@nestjs/common");
const cqrs_1 = require("@nestjs/cqrs");
const types_1 = require("./types");
const issuer_api_1 = require("@energyweb/issuer-api");
let BlockchainActionsProcessor = BlockchainActionsProcessor_1 = class BlockchainActionsProcessor {
    constructor(commandBus) {
        this.commandBus = commandBus;
        this.logger = new common_1.Logger(BlockchainActionsProcessor_1.name);
    }
    async handle(payload) {
        const result = await this.process(payload);
        await new Promise((resolve) => setTimeout(resolve, Number(process.env.CERTIFICATE_QUEUE_DELAY ?? 10000)));
        return result;
    }
    async process({ data }) {
        switch (data.type) {
            case types_1.BlockchainActionType.Issuance:
                const issuanceParams = data.payload;
                this.logger.debug(`Triggering issuance for: ${JSON.stringify(issuanceParams)}`);
                return await this.commandBus.execute(new issuer_api_1.IssueCertificateCommand(issuanceParams.toAddress, issuanceParams.energyValue.toString(), issuanceParams.fromTime, issuanceParams.toTime, issuanceParams.deviceId, issuanceParams.userId, false, JSON.stringify(issuanceParams.metadata)));
            case types_1.BlockchainActionType.Transfer:
                const transferParams = data.payload;
                this.logger.debug(`Triggering transfer for: ${JSON.stringify(transferParams)}`);
                return await this.commandBus.execute(new issuer_api_1.TransferCertificateCommand(transferParams.certificateId, transferParams.fromAddress, transferParams.toAddress, transferParams.energyValue
                    ? transferParams.energyValue.toString()
                    : undefined));
            case types_1.BlockchainActionType.Claim:
                const claimParams = data.payload;
                this.logger.debug(`Triggering claim for: ${JSON.stringify(claimParams)}`);
                return await this.commandBus.execute(new issuer_api_1.ClaimCertificateCommand(claimParams.certificateId, claimParams.claimData, claimParams.forAddress, claimParams.energyValue ? claimParams.energyValue.toString() : undefined));
        }
    }
};
__decorate([
    bull_1.Process({ concurrency: 1 }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], BlockchainActionsProcessor.prototype, "handle", null);
BlockchainActionsProcessor = BlockchainActionsProcessor_1 = __decorate([
    bull_1.Processor('blockchain-actions'),
    __metadata("design:paramtypes", [cqrs_1.CommandBus])
], BlockchainActionsProcessor);
exports.BlockchainActionsProcessor = BlockchainActionsProcessor;
//# sourceMappingURL=blockchain-actions.processor.js.map